<?php

	/**
	 * Hungarian language file for phpPgAdmin.
	 * maintainer: Sulyok P&eacute;ter &lt;peti@sulyok.hu&gt;
	 *
	 *
	 */

	// Language and character set
	$lang['applang'] = 'Magyar';
	$lang['appcharset'] = 'UTF-8';
	$lang['applocale'] = 'hu_HU';
	$lang['appdbencoding'] = 'LATIN2';
	$lang['applangdir'] = 'ltr';

	// Welcome  
	$lang['strintro'] = '&Uuml;dv&ouml;zli a phpPgAdmin!';
	$lang['strppahome'] = 'A phpPgAdmin honlapja';
	$lang['strpgsqlhome'] = 'A PostgreSQL honlapja';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'A PostgreSQL (helyi) dokument&aacute;ci&oacute;ja';
	$lang['strreportbug'] = 'Hibajelent&eacute;s felad&aacute;sa';
	$lang['strviewfaq'] = 'GYIK megtekint&eacute;se';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
	
	// Basic strings
	$lang['strlogin'] = 'Bejelentkez&eacute;s';
	$lang['strloginfailed'] = 'Sikertelen bejelentkez&eacute;s';
	$lang['strlogindisallowed'] = 'Nem enged&eacute;lyezett bejelentkez&eacute;s';
	$lang['strserver'] = 'Kiszolg&aacute;l&oacute;';
	$lang['strlogout'] = 'Kil&eacute;p&eacute;s';
	$lang['strowner'] = 'Tulajdonos';
	$lang['straction'] = 'M&#369;velet';
	$lang['stractions'] = 'M&#369;veletek';
	$lang['strname'] = 'N&eacute;v';
	$lang['strdefinition'] = 'Defin&iacute;ci&oacute;';
	$lang['strproperties'] = 'Tulajdons&aacute;gok';
	$lang['strbrowse'] = 'Tall&oacute;z&aacute;s';
	$lang['strdrop'] = 'T&ouml;rl&eacute;s';
	$lang['strdropped'] = 'T&ouml;rl&ouml;lve';
	$lang['strnull'] = 'Null';
	$lang['strnotnull'] = 'Not Null';
	$lang['strprev'] = '&lt; El&#337;z&#337;';
	$lang['strnext'] = 'K&ouml;vetkez&#337; &gt;';
	$lang['strfirst'] = '&lt;&lt; Els&#337;';
	$lang['strlast'] = 'Utols&oacute; &gt;&gt;';
	$lang['strfailed'] = 'Sikertelen';
	$lang['strcreate'] = 'Teremt&eacute;s';
	$lang['strcreated'] = 'Megteremtve';
	$lang['strcomment'] = 'Megjegyz&eacute;s';
	$lang['strlength'] = 'Hossz';
	$lang['strdefault'] = 'Alap&eacute;rtelmez&eacute;s';
	$lang['stralter'] = 'M&oacute;dos&iacute;t&aacute;s';
	$lang['strok'] = 'OK';
	$lang['strcancel'] = 'M&eacute;gsem';
	$lang['strsave'] = 'Ment&eacute;s';
	$lang['strreset'] = '&Uacute;jra';
	$lang['strinsert'] = 'Besz&uacute;r&aacute;s';
	$lang['strselect'] = 'Kiv&aacute;laszt&aacute;s';
	$lang['strdelete'] = 'T&ouml;rl&eacute;s';
	$lang['strupdate'] = 'Id&#337;szer&#369;s&iacute;t&eacute;s';
	$lang['strreferences'] = 'Hivatkoz&aacute;sok';
	$lang['stryes'] = 'Igen';
	$lang['strno'] = 'Nem';
	$lang['strtrue'] = 'IGAZ';
	$lang['strfalse'] = 'HAMIS';
	$lang['stredit'] = 'Szerkeszt&eacute;s';
	$lang['strcolumn']  = 'Oszlop';
	$lang['strcolumns'] = 'Oszlopok';
	$lang['strrows'] = 'sor';
	$lang['strrowsaff'] = 'sor &eacute;rintett.';
	$lang['strobjects'] = 'objektum';
	$lang['strexample'] = 'pl.';
	$lang['strback'] = 'Vissza';
	$lang['strqueryresults'] = 'Lek&eacute;rdez&eacute;s eredm&eacute;nyei';
	$lang['strshow'] = 'Megjelen&iacute;t&eacute;s';
	$lang['strempty'] = '&Uuml;r&iacute;t&eacute;s';
	$lang['strlanguage'] = 'Nyelv';
	$lang['strencoding'] = 'K&oacute;dol&aacute;s';
	$lang['strvalue'] = '&Eacute;rt&eacute;k';
	$lang['strunique'] = 'egyedi';
	$lang['strprimary'] = 'Els&#337;dleges';
	$lang['strexport'] = 'Export&aacute;l&aacute;s';
	$lang['strimport'] = 'Import&aacute;l&aacute;s';
	$lang['strsql'] = 'SQL';
	$lang['strgo'] = 'V&eacute;grehajt&aacute;s';
	$lang['stradmin'] = 'Gazda';
	$lang['strvacuum'] = 'Takar&iacute;t&aacute;s';
	$lang['stranalyze'] = 'Elemz&eacute;s';
	$lang['strcluster'] = 'F&uuml;rt&ouml;z&eacute;s';
	$lang['strclustered'] = 'F&uuml;rt&ouml;zve?';
	$lang['strreindex'] = '&Uacute;jraindexel&eacute;s';
	$lang['strrun'] = 'Futtat&aacute;s';
	$lang['stradd'] = 'B&#337;v&iacute;t&eacute;s';
	$lang['strevent'] = 'Esem&eacute;ny';
	$lang['strwhere'] = 'Hol';
	$lang['strinstead'] = 'Ink&aacute;bb';
	$lang['strwhen'] = 'Mikor';
	$lang['strformat'] = 'Alak';
	$lang['strdata'] = 'Adatok';
	$lang['strconfirm'] = 'Meger&#337;s&iacute;t&eacute;s';
	$lang['strexpression'] = 'Kifejez&eacute;s';
	$lang['strellipsis'] = '&hellip;';
	$lang['strseparator']  =  ': ';
	$lang['strexpand'] = 'Kinyit&aacute;s';
	$lang['strcollapse'] = '&Ouml;sszecsuk&aacute;s';
	$lang['strexplain'] = 'Kifejt&eacute;s';
	$lang['strexplainanalyze'] = 'Elemz&eacute;s kifejt&eacute;se';
	$lang['strfind'] = 'Keres&eacute;s';
	$lang['stroptions'] = 'R&eacute;szletek';
	$lang['strrefresh'] = 'Friss&iacute;t&eacute;s';
	$lang['strdownload'] = 'Let&ouml;lt&eacute;s';
	$lang['strdownloadgzipped'] = 'Gzippel t&ouml;m&ouml;r&iacute;tett let&ouml;lt&eacute;s';
	$lang['strinfo'] = 'Inf&oacute;';
	$lang['stroids'] = 'OID-k';
	$lang['stradvanced'] = 'Halad&oacute;';
	$lang['strvariables'] = 'V&aacute;ltoz&oacute;k';
	$lang['strprocess'] = 'Folyamat';
	$lang['strprocesses'] = 'Folyamatok';
	$lang['strsetting'] = 'Be&aacute;ll&iacute;t&aacute;s';
	$lang['streditsql'] = 'SQL-szerkeszt&eacute;s';
	$lang['strruntime'] = 'Teljes fut&aacute;si id&#337;: %s ms';
	$lang['strpaginate'] = 'Oldalakra t&ouml;rdel&eacute;s';
	$lang['struploadscript'] = 'vagy egy SQL-&iacute;r&aacute;s felt&ouml;lt&eacute;se:';
	$lang['strstarttime'] = 'Kezd&eacute;s ideje';
	$lang['strfile'] = 'F&aacute;jl';
	$lang['strfileimported'] = 'F&aacute;jl behozva.';

	// Error handling
	$lang['strnoframes'] = 'Ezen alkalmaz&aacute;s haszn&aacute;lat&aacute;hoz kereteket t&aacute;mogat&oacute; b&ouml;ng&eacute;sz&#337; sz&uuml;ks&eacute;ges.';
	$lang['strbadconfig'] = 'A config.inc.php elavult. &Uacute;jra kell teremteni az &uacute;j config.inc.php-dist f&aacute;jlb&oacute;l.';
	$lang['strnotloaded'] = 'Az &ouml;n PHP rendszere nem t&aacute;mogatja a PostgreSQL-t.';
	$lang['strphpversionnotsupported']  =  'A PHP e v&aacute;ltozata nem megfelel&#337;. K&eacute;rem telep&iacute;tse a %s v&aacute;ltozatot, vagy &uacute;jabbat!';
	$lang['strpostgresqlversionnotsupported']  =  'A PostgreSQL e v&aacute;ltozata nem megfelel&#337;. K&eacute;rem telep&iacute;tse a %s v&aacute;ltozatot, vagy &uacute;jabbat!';
	$lang['strbadschema'] = 'A megadott s&eacute;ma &eacute;rv&eacute;nytelen.';
	$lang['strbadencoding'] = 'Az &uuml;gyf&eacute;l oldali k&oacute;dol&aacute;s be&aacute;ll&iacute;t&aacute;sa az adatb&aacute;zisban nem siker&uuml;lt.';
	$lang['strsqlerror'] = 'SQL hiba:';
	$lang['strinstatement'] = 'A k&ouml;vetkez&#337; kifejez&eacute;sben:';
	$lang['strinvalidparam'] = '&Eacute;rv&eacute;nytelen &iacute;r&aacute;s-param&eacute;terek.';
	$lang['strnodata'] = 'Nincsenek sorok.';
	$lang['strnoobjects'] = 'Nincsenek objektumok.';
	$lang['strrownotunique'] = 'Nincs egyedi azonos&iacute;t&oacute; ehhez a sorhoz.';
	$lang['strnoreportsdb'] = '&Ouml;n m&eacute;g nem teremtette meg a jelent&eacute;sek adatb&aacute;zis&aacute;t. Olvassa el az INSTALL f&aacute;jlt tov&aacute;bbi &uacute;tmutat&aacute;s&eacute;rt!';
	$lang['strnouploads'] = 'F&aacute;jl felt&ouml;lt&eacute;se letiltva.';
	$lang['strimporterror'] = 'Behozatali hiba.';
	$lang['strimporterrorline'] = 'Behozatali hiba a %s. sorban.';

	// Tables
	$lang['strtable'] = 'T&aacute;bla';
	$lang['strtables'] = 'T&aacute;bl&aacute;k';
	$lang['strshowalltables'] = 'Minden t&aacute;bla megjelen&iacute;t&eacute;se';
	$lang['strnotables'] = 'Nincsenek t&aacute;bl&aacute;k.';
	$lang['strnotable'] = 'Nincs t&aacute;bla.';
	$lang['strcreatetable'] = 'T&aacute;bla teremt&eacute;se';
	$lang['strtablename'] = 'T&aacute;bla neve';
	$lang['strtableneedsname'] = 'Meg kell adni a t&aacute;bla nev&eacute;t.';
	$lang['strtableneedsfield'] = 'Legal&aacute;bb egy oszlopot meg kell adni.';
	$lang['strtableneedscols'] = 'A t&aacute;bl&aacute;nak &eacute;rv&eacute;nyes sz&aacute;m&uacute; oszlop kell.';
	$lang['strtablecreated'] = 'A t&aacute;bla megteremtve.';
	$lang['strtablecreatedbad'] = 'Nem siker&uuml;lt t&aacute;bl&aacute;t teremteni.';
	$lang['strconfdroptable'] = 'Biztosan t&ouml;r&ouml;lni k&iacute;v&aacute;nja &bdquo;%s&rdquo; t&aacute;bl&aacute;t?';
	$lang['strtabledropped'] = 'A t&aacute;bla t&ouml;r&ouml;lve.';
	$lang['strtabledroppedbad'] = 'Nem siker&uuml;lt a t&aacute;bl&aacute;t t&ouml;r&ouml;lni.';
	$lang['strconfemptytable'] = 'Biztosan ki akarja &uuml;r&iacute;teni &bdquo;%s&rdquo; t&aacute;bl&aacute;t?';
	$lang['strtableemptied'] = 'A t&aacute;bla ki&uuml;r&iacute;tve.';
	$lang['strtableemptiedbad'] = 'Nem siker&uuml;lt a t&aacute;bl&aacute;t ki&uuml;r&iacute;teni.';
	$lang['strinsertrow'] = 'Sor besz&uacute;r&aacute;sa';
	$lang['strrowinserted'] = 'A sor besz&uacute;rva.';
	$lang['strrowinsertedbad'] = 'Nem siker&uuml;lt a sort besz&uacute;rni.';
	$lang['streditrow'] = 'Sor szerkeszt&eacute;se';
	$lang['strrowupdated'] = 'A sor id&#337;szer&#369;s&iacute;tve.';
	$lang['strrowupdatedbad'] = 'Nem siker&uuml;lt a sort id&#337;szer&#369;s&iacute;teni.';
	$lang['strdeleterow'] = 'Sor t&ouml;rl&eacute;se';
	$lang['strconfdeleterow'] = 'Biztosan t&ouml;r&ouml;lni k&iacute;v&aacute;nja ezt a sort?';
	$lang['strrowdeleted'] = 'A sor t&ouml;r&ouml;lve.';
	$lang['strrowdeletedbad'] = 'Nem siker&uuml;lt a sort t&ouml;r&ouml;lni.';
	$lang['strinsertandrepeat']  =  'Besz&uacute;r&aacute;s &amp; Ism&eacute;tl&eacute;s';
	$lang['strnumcols']  =  'Oszlopok sz&aacute;ma';
	$lang['strcolneedsname']  =  'Meg kell adnia az oszlop nev&eacute;t';
	$lang['strselectallfields'] = 'Minden oszlop kijel&ouml;l&eacute;se';
	$lang['strselectneedscol'] = 'Ki kell v&aacute;lasztani egy oszlopot';
	$lang['strselectunary'] = 'Egyv&aacute;ltoz&oacute;s m&#369;veleteknek nem lehetnek &eacute;rt&eacute;kei';
	$lang['straltercolumn'] = 'Oszlop megv&aacute;ltoztat&aacute;sa';
	$lang['strcolumnaltered'] = 'Az oszlop megv&aacute;ltoztatva.';
	$lang['strcolumnalteredbad'] = 'Nem siker&uuml;lt az oszlopot megv&aacute;ltoztatni.';
	$lang['strconfdropcolumn'] = 'Biztosan t&ouml;r&ouml;lni k&iacute;v&aacute;nja &bdquo;%s&rdquo; oszlopot &bdquo;%s&rdquo; t&aacute;bl&aacute;b&oacute;l?';
	$lang['strcolumndropped'] = 'Az oszlop t&ouml;r&ouml;lve.';
	$lang['strcolumndroppedbad'] = 'Nem siker&uuml;lt az oszlopot t&ouml;r&ouml;lni.';
	$lang['straddcolumn'] = 'Oszloppal b&#337;v&iacute;t&eacute;s';
	$lang['strcolumnadded'] = 'Oszloppal b&#337;v&iacute;tve.';
	$lang['strcolumnaddedbad'] = 'Nem siker&uuml;lt az oszloppal b&#337;v&iacute;teni.';
	$lang['strcascade'] = 'ZUHATAG';
	$lang['strtablealtered'] = 'A t&aacute;bla megv&aacute;ltoztatva.';
	$lang['strtablealteredbad'] = 'Nem siker&uuml;lt a t&aacute;bl&aacute;t megv&aacute;ltoztatni.';
	$lang['strdataonly'] = 'Csak adatok';
	$lang['strstructureonly'] = 'Csak strukt&uacute;ra';
	$lang['strstructureanddata'] = 'Strukt&uacute;ra &eacute;s adatok';
	$lang['strtabbed'] = 'F&uuml;les';
	$lang['strauto'] = 'Aut&oacute;';
	$lang['strconfvacuumtable']  =  'Biztosan ki akarja takar&iacute;tani &bdquo;%s&rdquo; t&aacute;bl&aacute;t?';
	$lang['strestimatedrowcount']  =  'Becs&uuml;lt sorok sz&aacute;ma';

	// Users
	$lang['struser'] = 'Felhaszn&aacute;l&oacute;';
	$lang['strusers'] = 'Felhaszn&aacute;l&oacute;k';
	$lang['strusername'] = 'Felhaszn&aacute;l&oacute;n&eacute;v';
	$lang['strpassword'] = 'Jelsz&oacute;';
	$lang['strsuper'] = 'Rendszergazda?';
	$lang['strcreatedb'] = 'L&eacute;trehozhat AB-t?';
	$lang['strexpires'] = 'Lej&aacute;r';
	$lang['strsessiondefaults'] = 'Munkamenet alap&eacute;rt&eacute;kei';
	$lang['strnousers']  =  'Nincsenek felhaszn&aacute;l&oacute;k.';
	$lang['struserupdated'] = 'A felhaszn&aacute;l&oacute; id&#337;szer&#369;s&iacute;tve.';
	$lang['struserupdatedbad'] = 'Nem siker&uuml;lt a felhaszn&aacute;l&oacute;t id&#337;szer&#369;s&iacute;teni.';
	$lang['strshowallusers'] = 'Minden felhaszn&aacute;l&oacute; megjelen&iacute;t&eacute;se';
	$lang['strcreateuser'] = 'Felhaszn&aacute;l&oacute; teremt&eacute;se';
	$lang['struserneedsname'] = 'A felhaszn&aacute;l&oacute;nak nevet kell adni.';
	$lang['strusercreated'] = 'A felhaszn&aacute;l&oacute; megteremtve.';
	$lang['strusercreatedbad'] = 'Nem siker&uuml;lt a felhaszn&aacute;l&oacute;t megteremteni.';
	$lang['strconfdropuser'] = 'Biztosan t&ouml;r&ouml;lni akarja &bdquo;%s&rdquo; felhaszn&aacute;l&oacute;t?';
	$lang['struserdropped'] = 'A felhaszn&aacute;l&oacute; t&ouml;r&ouml;lve.';
	$lang['struserdroppedbad'] = 'Nem siker&uuml;lt a felhaszn&aacute;l&oacute;t t&ouml;r&ouml;lni.';
	$lang['straccount'] = 'Sz&aacute;mla';
	$lang['strchangepassword'] = 'Jelsz&oacute; megv&aacute;ltoztat&aacute;sa';
	$lang['strpasswordchanged'] = 'A jelsz&oacute; megv&aacute;ltoztatva.';
	$lang['strpasswordchangedbad'] = 'Nem siker&uuml;lt a jelsz&oacute;t megv&aacute;ltoztatni.';
	$lang['strpasswordshort'] = 'A jelsz&oacute; t&uacute;l r&ouml;vid.';
	$lang['strpasswordconfirm'] = 'A jelsz&oacute; nem egyezik a meger&#337;s&iacute;t&eacute;ssel.';
	
	// Groups
	$lang['strgroup'] = 'Csoport';
	$lang['strgroups'] = 'Csoportok';
	$lang['strnogroup'] = 'Nincs csoport.';
	$lang['strnogroups'] = 'Nincsenek csoportok.';
	$lang['strcreategroup'] = 'Csoport teremt&eacute;se';
	$lang['strshowallgroups'] = 'Minden csoport megjelen&iacute;t&eacute;se';
	$lang['strgroupneedsname'] = 'A csoportnak nevet kell adni.';
	$lang['strgroupcreated'] = 'A csoport megteremtve.';
	$lang['strgroupcreatedbad'] = 'Nem siker&uuml;lt a csoportot megteremteni.';	
	$lang['strconfdropgroup'] = 'Biztosan t&ouml;r&ouml;lni k&iacute;v&aacute;nja &bdquo;%s&rdquo; csoportot?';
	$lang['strgroupdropped'] = 'A csoport t&ouml;r&ouml;lve.';
	$lang['strgroupdroppedbad'] = 'Nem siker&uuml;lt a csoportot t&ouml;r&ouml;lni.';
	$lang['strmembers'] = 'Tagok';
	$lang['straddmember'] = 'Tag felv&eacute;tele';
	$lang['strmemberadded'] = 'Tag felv&eacute;ve.';
	$lang['strmemberaddedbad'] = 'Nem siker&uuml;lt tagot felvenni.';
	$lang['strdropmember'] = 'Tag kicsap&aacute;sa';
	$lang['strconfdropmember'] = 'Biztosan ki akarja csapni &bdquo;%s&rdquo; tagot &bdquo;%s&rdquo; csoportb&oacute;l?';
	$lang['strmemberdropped'] = 'A tag kicsapva.';
	$lang['strmemberdroppedbad'] = 'Nem siker&uuml;lt a tagot kicsapni.';

	// Privileges
	$lang['strprivilege'] = 'Jogosults&aacute;g';
	$lang['strprivileges'] = 'Jogosults&aacute;gok';
	$lang['strnoprivileges'] = 'Ez az objektum alap-jogosults&aacute;gokkal rendelkezik.';
	$lang['strgrant'] = 'Feljogos&iacute;t&aacute;s';
	$lang['strrevoke'] = 'Jogosults&aacute;g megvon&aacute;sa';
	$lang['strgranted'] = 'A jogosults&aacute;gok megv&aacute;ltoztatva.';
	$lang['strgrantfailed'] = 'Nem siker&uuml;lt a jogosults&aacute;gokat megv&aacute;ltoztatni.';
	$lang['strgrantbad'] = 'Legal&aacute;bb egy felhaszn&aacute;l&oacute;t &eacute;s jogosults&aacute;got ki kell v&aacute;lasztani.';
	$lang['strgrantor'] = 'Jogos&iacute;t&oacute;';
	$lang['strasterisk'] = '*';

	// Databases
	$lang['strdatabase'] = 'Adatb&aacute;zis';
	$lang['strdatabases'] = 'Adatb&aacute;zisok';
	$lang['strshowalldatabases'] = 'Minden adatb&aacute;zis megjelen&iacute;t&eacute;se';
	$lang['strnodatabase'] = 'Nincs adatb&aacute;zis.';
	$lang['strnodatabases'] = 'Nincsenek adatb&aacute;zisok.';
	$lang['strcreatedatabase'] = 'Adatb&aacute;zis teremt&eacute;se';
	$lang['strdatabasename'] = 'Adatb&aacute;zisn&eacute;v';
	$lang['strdatabaseneedsname'] = 'Meg kell adni az adatb&aacute;zisnevet.';
	$lang['strdatabasecreated'] = 'Az adatb&aacute;zis megteremtve.';
	$lang['strdatabasecreatedbad'] = 'Nem siker&uuml;lt megteremteni az adatb&aacute;zist.';
	$lang['strconfdropdatabase'] = 'Biztosan t&ouml;r&ouml;lni akarja &bdquo;%s&rdquo; adatb&aacute;zist?';
	$lang['strdatabasedropped'] = 'Az adatb&aacute;zis t&ouml;r&ouml;lve.';
	$lang['strdatabasedroppedbad'] = 'Nem siker&uuml;lt t&ouml;r&ouml;lni az adatb&aacute;zist.';
	$lang['strentersql'] = '&Iacute;rja be a v&eacute;grehajtand&oacute; SQL-kifejez&eacute;seket ide:';
	$lang['strsqlexecuted'] = 'Az SQL-kifejez&eacute;sek v&eacute;grehajtva.';
	$lang['strvacuumgood'] = 'A takar&iacute;t&aacute;s k&eacute;sz.';
	$lang['strvacuumbad'] = 'Nem siker&uuml;lt kitakar&iacute;tani.';
	$lang['stranalyzegood'] = 'Az elemz&eacute;s k&eacute;sz.';
	$lang['stranalyzebad'] = 'Nem siker&uuml;lt kielemezni.';
	$lang['strreindexgood'] = '&Uacute;jraindexel&eacute;s k&eacute;sz.';
	$lang['strreindexbad'] = '&Uacute;jraindexel&eacute;s sikertelen.';
	$lang['strfull'] = 'Teljes';
	$lang['strfreeze'] = 'Befagyaszt&aacute;s';
	$lang['strforce'] = 'K&eacute;nyszer&iacute;t&eacute;s';
	$lang['strsignalsent']  =  'Jelz&eacute;s elk&uuml;ldve.';
	$lang['strsignalsentbad']  =  'Jelz&eacute;s elk&uuml;ld&eacute;se sikertelen.';
	$lang['strallobjects']  =  'Minden objektum';

	// Views
	$lang['strview'] = 'N&eacute;zet';
	$lang['strviews'] = 'N&eacute;zetek';
	$lang['strshowallviews'] = 'Minden n&eacute;zet megjelen&iacute;t&eacute;se';
	$lang['strnoview'] = 'Nincs n&eacute;zet.';
	$lang['strnoviews'] = 'Nincsenek n&eacute;zetek.';
	$lang['strcreateview'] = 'N&eacute;zet teremt&eacute;se';
	$lang['strviewname'] = 'N&eacute;zetn&eacute;v';
	$lang['strviewneedsname'] = 'Meg kell adni a n&eacute;zetnevet.';
	$lang['strviewneedsdef'] = 'Meg kell adni a n&eacute;zet defin&iacute;ci&oacute;j&aacute;t.';
	$lang['strviewneedsfields'] = 'Meg kell adnia a oszlopokat, amiket ki akar jel&ouml;lni a n&eacute;zetben.';
	$lang['strviewcreated'] = 'A n&eacute;zet megteremtve.';
	$lang['strviewcreatedbad'] = 'Nem siker&uuml;lt megteremteni a n&eacute;zetet.';
	$lang['strconfdropview'] = 'Biztosan t&ouml;r&ouml;lni k&iacute;v&aacute;nja &bdquo;%s&rdquo; n&eacute;zetet?';
	$lang['strviewdropped'] = 'A n&eacute;zet t&ouml;r&ouml;lve.';
	$lang['strviewdroppedbad'] = 'Nem siker&uuml;lt t&ouml;r&ouml;lni a n&eacute;zetet.';
	$lang['strviewupdated'] = 'A n&eacute;zet id&#337;szer&#369;s&iacute;tve.';
	$lang['strviewupdatedbad'] = 'Nem siker&uuml;lt id&#337;szer&#369;s&iacute;teni a n&eacute;zetet.';
	$lang['strviewlink'] = 'Hivatkoz&aacute;sok';
	$lang['strviewconditions'] = 'Tov&aacute;bbi felt&eacute;telek';
	$lang['strcreateviewwiz'] = 'N&eacute;zet teremt&eacute;se var&aacute;zsl&oacute;val';

	// Sequences
	$lang['strsequence'] = 'Sorozat';
	$lang['strsequences'] = 'Sorozatok';
	$lang['strshowallsequences'] = 'Minden sorozat megjelen&iacute;t&eacute;se';
	$lang['strnosequence'] = 'Nincs sorozat.';
	$lang['strnosequences'] = 'Nincsenek sorozatok.';
	$lang['strcreatesequence'] = 'Sorozat teremt&eacute;se';
	$lang['strlastvalue'] = 'Utols&oacute; &eacute;rt&eacute;k';
	$lang['strincrementby'] = 'N&ouml;vekm&eacute;ny';	
	$lang['strstartvalue'] = 'Kezd&#337;&eacute;rt&eacute;k';
	$lang['strmaxvalue'] = 'Fels&#337; korl&aacute;t';
	$lang['strminvalue'] = 'Als&oacute; korl&aacute;t';
	$lang['strcachevalue'] = 'Gyorst&aacute;r &eacute;rt&eacute;ke';
	$lang['strlogcount'] = 'Sz&aacute;ml&aacute;l&oacute;';
	$lang['striscycled'] = 'Ciklikus?';
	$lang['striscalled'] = 'Hivatkozott?';
	$lang['strsequenceneedsname'] = 'Meg kell adni a sorozatnevet.';
	$lang['strsequencecreated'] = 'A sorozat megteremtve.';
	$lang['strsequencecreatedbad'] = 'Nem siker&uuml;lt megteremteni a sorozatot.'; 
	$lang['strconfdropsequence'] = 'Biztosan t&ouml;r&ouml;lni k&iacute;v&aacute;nja &bdquo;%s&rdquo; sorozatot?';
	$lang['strsequencedropped'] = 'A sorozat t&ouml;r&ouml;lve.';
	$lang['strsequencedroppedbad'] = 'Nem siker&uuml;lt t&ouml;r&ouml;lni a sorozatot.';
	$lang['strsequencereset'] = 'Sorozat null&aacute;z&aacute;sa.';
	$lang['strsequenceresetbad'] = 'Nem siker&uuml;lt null&aacute;zni a sorozatot.'; 

	// Indexes
	$lang['strindex'] = 'Index';
	$lang['strindexes']  =  'Indexek';
	$lang['strindexname'] = 'Indexn&eacute;v';
	$lang['strshowallindexes'] = 'Minden index megjelen&iacute;t&eacute;se';
	$lang['strnoindex'] = 'Nincs index.';
	$lang['strnoindexes'] = 'Nincsenek indexek.';
	$lang['strcreateindex'] = 'Index l&eacute;trehoz&aacute;sa';
	$lang['strtabname'] = 'T&aacute;blan&eacute;v';
	$lang['strcolumnname'] = 'Oszlopn&eacute;v';
	$lang['strindexneedsname'] = 'Meg kell adni az index nev&eacute;t.';
	$lang['strindexneedscols'] = 'Meg kell adni az oszlopok (&eacute;rv&eacute;nyes) sz&aacute;m&aacute;t.';
	$lang['strindexcreated'] = 'Az index megteremtve';
	$lang['strindexcreatedbad'] = 'Nem siker&uuml;lt megteremteni az indexet.';
	$lang['strconfdropindex'] = 'Biztosan t&ouml;r&ouml;lni k&iacute;v&aacute;nja &bdquo;%s&rdquo; indexet?';
	$lang['strindexdropped'] = 'Az index t&ouml;r&ouml;lve.';
	$lang['strindexdroppedbad'] = 'Nem siker&uuml;lt t&ouml;r&ouml;lni az indexet.';
	$lang['strkeyname'] = 'Kulcsn&eacute;v';
	$lang['struniquekey'] = 'Egyedi kulcs';
	$lang['strprimarykey'] = 'Els&#337;dleges kulcs';
 	$lang['strindextype'] = 'Indext&iacute;pus';
	$lang['strtablecolumnlist'] = 'A t&aacute;bla oszlopai';
	$lang['strindexcolumnlist'] = 'Az index oszlopai';
	$lang['strconfcluster'] = 'Biztosan f&uuml;rt&ouml;zni k&iacute;v&aacute;nja &bdquo;%s&rdquo;-t?';
	$lang['strclusteredgood'] = 'F&uuml;rt&ouml;z&eacute;s k&eacute;sz.';
	$lang['strclusteredbad'] = 'F&uuml;rt&ouml;z&eacute;s sikertelen.';

	// Rules
	$lang['strrules'] = 'Szab&aacute;lyok';
	$lang['strrule'] = 'Szab&aacute;ly';
	$lang['strshowallrules'] = 'Minden szab&aacute;ly megjelen&iacute;t&eacute;se';
	$lang['strnorule'] = 'Nincs szab&aacute;ly.';
	$lang['strnorules'] = 'Nincsenek szab&aacute;lyok.';
	$lang['strcreaterule'] = 'Szab&aacute;ly teremt&eacute;se';
	$lang['strrulename'] = 'Szab&aacute;lyn&eacute;v';
	$lang['strruleneedsname'] = 'Meg kell adni a szab&aacute;lynevet.';
	$lang['strrulecreated'] = 'A szab&aacute;ly megteremtve.';
	$lang['strrulecreatedbad'] = 'Nem siker&uuml;lt megteremteni a szab&aacute;lyt.';
	$lang['strconfdroprule'] = 'Biztosan t&ouml;r&ouml;lni k&iacute;v&aacute;nja &bdquo;%s&rdquo; szab&aacute;lyt &bdquo;%s&rdquo; t&aacute;bl&aacute;ban?';
	$lang['strruledropped'] = 'A szab&aacute;ly t&ouml;r&ouml;lve.';
	$lang['strruledroppedbad'] = 'Nem siker&uuml;lt t&ouml;r&ouml;lni a szab&aacute;lyt.';

	// Constraints
	$lang['strconstraints'] = 'Megszor&iacute;t&aacute;sok';
	$lang['strshowallconstraints'] = 'Minden megszor&iacute;t&aacute;s megjelen&iacute;t&eacute;se';
	$lang['strnoconstraints'] = 'Nincsenek megszor&iacute;t&aacute;sok.';
	$lang['strcreateconstraint'] = 'Megszor&iacute;t&aacute;s teremt&eacute;se';
	$lang['strconstraintcreated'] = 'A megszor&iacute;t&aacute;s megteremtve.';
	$lang['strconstraintcreatedbad'] = 'Nem siker&uuml;lt megteremteni a megszor&iacute;t&aacute;st.';
	$lang['strconfdropconstraint'] = 'Biztosan t&ouml;r&ouml;lni k&iacute;v&aacute;nja &bdquo;%s&rdquo; megszor&iacute;t&aacute;st &bdquo;%s&rdquo; t&aacute;bl&aacute;ban?';
	$lang['strconstraintdropped'] = 'A megszor&iacute;t&aacute;s t&ouml;r&ouml;lve.';
	$lang['strconstraintdroppedbad'] = 'Nem siker&uuml;lt t&ouml;r&ouml;lni a megszor&iacute;t&aacute;st.';
	$lang['straddcheck'] = 'Ellen&#337;rz&eacute;s hozz&aacute;ad&aacute;sa';
	$lang['strcheckneedsdefinition'] = 'Meg kell adni az ellen&#337;rz&eacute;s defin&iacute;ci&oacute;j&aacute;t.';
	$lang['strcheckadded'] = 'Az ellen&#337;rz&eacute;s hozz&aacute;adva.';
	$lang['strcheckaddedbad'] = 'Nem siker&uuml;lt hozz&aacute;adni az ellen&#337;rz&eacute;st.';
	$lang['straddpk'] = 'Els&#337;dleges kulcs hozz&aacute;ad&aacute;sa';
	$lang['strpkneedscols'] = 'Legal&aacute;bb egy oszlopot meg kell adni els&#337;dleges kulcsnak.';
	$lang['strpkadded'] = 'Els&#337;dleges kulcs hozz&aacute;adva.';
	$lang['strpkaddedbad'] = 'Nem siker&uuml;lt hozz&aacute;adni az els&#337;dleges kulcsot.';
	$lang['stradduniq'] = 'egyedi kulcs hozz&aacute;ad&aacute;sa';
	$lang['struniqneedscols'] = 'Legal&aacute;bb egy oszlopot meg kell adni egyedi kulcsnak.';
	$lang['struniqadded'] = 'Az egyedi kulcs hozz&aacute;adva.';
	$lang['struniqaddedbad'] = 'Nem siker&uuml;lt hozz&aacute;adni az egyedi kulcsot.';
	$lang['straddfk'] = 'K&uuml;ls&#337; kulcs hozz&aacute;ad&aacute;sa';
	$lang['strfkneedscols'] = 'Legal&aacute;bb egy oszlopot meg kell adni k&uuml;ls&#337; kulcsnak.';
	$lang['strfkneedstarget'] = 'Meg kell adni a c&eacute;lt&aacute;bl&aacute;t a k&uuml;ls&#337; kulcsnak.';
	$lang['strfkadded'] = 'A k&uuml;ls&#337; kulcs hozz&aacute;adva.';
	$lang['strfkaddedbad'] = 'Nem siker&uuml;lt hozz&aacute;adni a k&uuml;ls&#337; kulcsot.';
	$lang['strfktarget'] = 'C&eacute;lt&aacute;bla';
	$lang['strfkcolumnlist'] = 'Kulcsoszlopok';
	$lang['strondelete'] = 'T&Ouml;RL&Eacute;SKOR';
	$lang['stronupdate'] = 'ID&#336;SZER&#368;S&Iacute;T&Eacute;SKOR';

	// Functions
	$lang['strfunction'] = 'F&uuml;ggv&eacute;ny';
	$lang['strfunctions'] = 'F&uuml;ggv&eacute;nyek';
	$lang['strshowallfunctions'] = 'Minden f&uuml;ggv&eacute;ny megjelen&iacute;t&eacute;se';
	$lang['strnofunction'] = 'Nincs f&uuml;ggv&eacute;ny.';
	$lang['strnofunctions'] = 'Nincsenek f&uuml;ggv&eacute;nyek.';
	$lang['strcreateplfunction']  =  'SQL/PL f&uuml;ggv&eacute;ny teremt&eacute;se';
	$lang['strcreateinternalfunction']  =  'Bels&#337; f&uuml;ggv&eacute;ny teremt&eacute;se';
	$lang['strcreatecfunction']  =  'C f&uuml;ggv&eacute;ny teremt&eacute;se';
	$lang['strfunctionname'] = 'F&uuml;ggv&eacute;nyn&eacute;v';
	$lang['strreturns'] = 'Visszar&eacute;r&eacute;si &eacute;rt&eacute;k';
	$lang['strarguments'] = 'Argumentumok';
	$lang['strproglanguage'] = 'Programoz&aacute;si nyelv';
	$lang['strfunctionneedsname'] = 'Meg kell adni a f&uuml;ggv&eacute;ny nev&eacute;t.';
	$lang['strfunctionneedsdef'] = 'Meg kell adni a f&uuml;ggv&eacute;ny defin&iacute;ci&oacute;j&aacute;t.';
	$lang['strfunctioncreated'] = 'A f&uuml;ggv&eacute;ny megteremtve.';
	$lang['strfunctioncreatedbad'] = 'Nem siker&uuml;lt megteremteni a f&uuml;ggv&eacute;nyt.';
	$lang['strconfdropfunction'] = 'Biztosan t&ouml;r&ouml;lni k&iacute;v&aacute;nja &bdquo;%s&rdquo; f&uuml;ggv&eacute;nyt?';
	$lang['strfunctiondropped'] = 'A f&uuml;ggv&eacute;ny t&ouml;r&ouml;lve.';
	$lang['strfunctiondroppedbad'] = 'Nem siker&uuml;lt t&ouml;r&ouml;lni a f&uuml;ggv&eacute;nyt.';
	$lang['strfunctionupdated'] = 'A f&uuml;ggv&eacute;ny id&#337;szer&#369;s&iacute;tve.';
	$lang['strfunctionupdatedbad'] = 'Nem siker&uuml;lt a f&uuml;ggv&eacute;nyt id&#337;szer&#369;s&iacute;teni.';
	$lang['strobjectfile']  =  'Object f&aacute;jl';
	$lang['strlinksymbol']  =  'Szerkeszt&eacute;si szimb&oacute;lum';

	// Triggers
	$lang['strtrigger'] = 'Trigger';
	$lang['strtriggers'] = 'Triggerek';
	$lang['strshowalltriggers'] = 'Minden trigger megjelen&iacute;t&eacute;se';
	$lang['strnotrigger'] = 'Nincs trigger.';
	$lang['strnotriggers'] = 'Nincsenek triggerek.';
	$lang['strcreatetrigger'] = 'Trigger teremt&eacute;se';
	$lang['strtriggerneedsname'] = 'Meg kell adni a trigger nev&eacute;t.';
	$lang['strtriggerneedsfunc'] = 'Meg kell adni egy f&uuml;ggv&eacute;ny nev&eacute;t a triggerhez.';
	$lang['strtriggercreated'] = 'A trigger megteremtve.';
	$lang['strtriggercreatedbad'] = 'Nem siker&uuml;lt megteremteni a triggert.';
	$lang['strconfdroptrigger'] = 'Biztosan t&ouml;r&ouml;lni k&iacute;v&aacute;nja &bdquo;%s&rdquo; triggert &bdquo;%s&rdquo; t&aacute;bl&aacute;ban?';
	$lang['strtriggerdropped'] = 'A trigger t&ouml;r&ouml;lve.';
	$lang['strtriggerdroppedbad'] = 'Nem siker&uuml;lt t&ouml;r&ouml;lni a triggert.';
	$lang['strtriggeraltered'] = 'A trigger megv&aacute;ltoztatva.';
	$lang['strtriggeralteredbad'] = 'Nem siker&uuml;lt megv&aacute;ltoztatni a triggert.';

	// Types
	$lang['strtype'] = 'T&iacute;pus';
	$lang['strtypes'] = 'T&iacute;pusok';
	$lang['strshowalltypes'] = 'Minden t&iacute;pus megjelen&iacute;t&eacute;se';
	$lang['strnotype'] = 'Nincs t&iacute;pus.';
	$lang['strnotypes'] = 'Nincsenek t&iacute;pusok.';
	$lang['strcreatetype'] = 'T&iacute;pus teremt&eacute;se';
	$lang['strcreatecomptype']  =  '&Ouml;sszetett t&iacute;pus teremt&eacute;se';
	$lang['strtypeneedsfield']  =  'Legal&aacute;bb egy oszlopot meg kell adnia.';
	$lang['strtypeneedscols']  =  '&Eacute;rv&eacute;nyes oszlopsz&aacute;mot kell megadnia.';	
	$lang['strtypename'] = 'T&iacute;pusn&eacute;v';
	$lang['strinputfn'] = 'Beviteli f&uuml;ggv&eacute;ny';
	$lang['stroutputfn'] = 'Kiviteli f&uuml;ggv&eacute;ny';
	$lang['strpassbyval'] = '&Eacute;rt&eacute;k szerinti &aacute;tad&aacute;s?';
	$lang['stralignment'] = 'Igaz&iacute;t&aacute;s';
	$lang['strelement'] = 'Elem';
	$lang['strdelimiter'] = 'Hat&aacute;rol&oacute;';
	$lang['strstorage'] = 'T&aacute;r';
	$lang['strfield']  =  'Oszlop';
	$lang['strnumfields']  =  'Oszlopok sz&aacute;ma';
	$lang['strtypeneedsname'] = 'Meg kell adni a t&iacute;pusnevet.';
	$lang['strtypeneedslen'] = 'Meg kell adni a t&iacute;pus hossz&aacute;t.';
	$lang['strtypecreated'] = 'A t&iacute;pus megteremtve';
	$lang['strtypecreatedbad'] = 'Nem siker&uuml;lt megteremteni a t&iacute;pust.';
	$lang['strconfdroptype'] = 'Biztosan t&ouml;r&ouml;lni k&iacute;v&aacute;nja &bdquo;%s&rdquo; t&iacute;pust?';
	$lang['strtypedropped'] = 'A t&iacute;pus t&ouml;r&ouml;lve.';
	$lang['strtypedroppedbad'] = 'Nem siker&uuml;lt t&ouml;r&ouml;lni a t&iacute;pust.';
	$lang['strflavor']  =  'Fajta';
	$lang['strbasetype']  =  'Alap';
	$lang['strcompositetype']  =  '&Ouml;sszetett';
	$lang['strpseudotype']  =  '&Aacute;l';

	// Schemas
	$lang['strschema'] = 'S&eacute;ma';
	$lang['strschemas'] = 'S&eacute;m&aacute;k';
	$lang['strshowallschemas'] = 'Minden s&eacute;ma megjelen&iacute;t&eacute;se';
	$lang['strnoschema'] = 'Nincs s&eacute;ma.';
	$lang['strnoschemas'] = 'Nincsenek s&eacute;m&aacute;k.';
	$lang['strcreateschema'] = 'S&eacute;ma teremt&eacute;se';
	$lang['strschemaname'] = 'S&eacute;man&eacute;v';
	$lang['strschemaneedsname'] = 'Meg kell adni a s&eacute;manevet.';
	$lang['strschemacreated'] = 'A s&eacute;ma megteremtve';
	$lang['strschemacreatedbad'] = 'Nem siker&uuml;lt a s&eacute;m&aacute;t megteremteni.';
	$lang['strconfdropschema'] = 'Biztosan t&ouml;r&ouml;lni k&iacute;v&aacute;nja &bdquo;%s&rdquo; s&eacute;m&aacute;t?';
	$lang['strschemadropped'] = 'A s&eacute;ma t&ouml;r&ouml;lve.';
	$lang['strschemadroppedbad'] = 'Nem siker&uuml;lt a s&eacute;m&aacute;t t&ouml;r&ouml;lni.';
	$lang['strschemaaltered'] = 'S&eacute;ma megv&aacute;ltoztatva.';
	$lang['strschemaalteredbad'] = 'S&eacute;ma magv&aacute;ltoztat&aacute;sa sikertelen.';
	$lang['strsearchpath']  =  'S&eacute;ma keres&eacute;si &uacute;tvonala';

	// Reports
	$lang['strreport'] = 'Jelent&eacute;s';
	$lang['strreports'] = 'Jelent&eacute;sek';
	$lang['strshowallreports'] = 'Minden jelent&eacute;s megjelen&iacute;t&eacute;se';
	$lang['strnoreports'] = 'Nincsenek jelent&eacute;sek.';
	$lang['strcreatereport'] = 'Jelent&eacute;s teremt&eacute;se';
	$lang['strreportdropped'] = 'A jelent&eacute;s t&ouml;r&ouml;lve.';
	$lang['strreportdroppedbad'] = 'Nem siker&uuml;lt t&ouml;r&ouml;lni a jelent&eacute;st.';
	$lang['strconfdropreport'] = 'Biztosan t&ouml;r&ouml;lni k&iacute;v&aacute;nja &bdquo;%s&rdquo; jelent&eacute;st?';
	$lang['strreportneedsname'] = 'Meg kell adni a jelent&eacute;snevet.';
	$lang['strreportneedsdef'] = 'SQL kifejez&eacute;st kell hozz&aacute;adni a jelent&eacute;shez.';
	$lang['strreportcreated'] = 'A jelent&eacute;s megteremtve.';
	$lang['strreportcreatedbad'] = 'Nem siker&uuml;lt megteremteni a jelent&eacute;st.';

	// Domains
	$lang['strdomain'] = 'Tartom&aacute;ny';
	$lang['strdomains'] = 'Tartom&aacute;nyok';
	$lang['strshowalldomains'] = 'Minden tartom&aacute;ny megjelen&iacute;t&eacute;se';
	$lang['strnodomains'] = 'Nincsnek tartom&aacute;nyok.';
	$lang['strcreatedomain'] = 'Tartom&aacute;ny teremt&eacute;se';
	$lang['strdomaindropped'] = 'A tartom&aacute;ny t&ouml;r&ouml;lve.';
	$lang['strdomaindroppedbad'] = 'Nem siker&uuml;lt t&ouml;r&ouml;lni a tartom&aacute;nyt.';
	$lang['strconfdropdomain'] = 'Biztosan t&ouml;r&ouml;lni k&iacute;v&aacute;nja &bdquo;%s&rdquo; tartom&aacute;nyt?';
	$lang['strdomainneedsname'] = 'Meg kell adni a tartom&aacute;nynevet.';
	$lang['strdomaincreated'] = 'A tartom&aacute;ny megteremtve.';
	$lang['strdomaincreatedbad'] = 'Nem siker&uuml;lt megteremteni a tartom&aacute;nyt.';	
	$lang['strdomainaltered'] = 'A tartom&aacute;ny megv&aacute;ltoztatva.';
	$lang['strdomainalteredbad'] = 'Nem siker&uuml;lt megv&aacute;ltoztatni a tartom&aacute;nyt.';	

	// Operators
	$lang['stroperator'] = 'Oper&aacute;tor';
	$lang['stroperators'] = 'Oper&aacute;torok';
	$lang['strshowalloperators'] = 'Minden oper&aacute;tor megjelen&iacute;t&eacute;se';
	$lang['strnooperator'] = 'Nincs oper&aacute;tor.';
	$lang['strnooperators'] = 'Nincsenek oper&aacute;torok.';
	$lang['strcreateoperator'] = 'Oper&aacute;tor teremt&eacute;se';
	$lang['strleftarg'] = 'Bal arg t&iacute;pus';
	$lang['strrightarg'] = 'Jobb arg t&iacute;pus';
	$lang['strcommutator'] = 'Kommut&aacute;tor';
	$lang['strnegator'] = 'Tagad&oacute;';
	$lang['strrestrict'] = 'Megszor&iacute;t&aacute;s';
	$lang['strjoin'] = '&Ouml;sszekapcsol&aacute;s';
	$lang['strhashes'] = 'Has&iacute;t';
	$lang['strmerges'] = '&Ouml;sszef&eacute;s&uuml;l';
	$lang['strleftsort'] = 'Balrendez&eacute;s';
	$lang['strrightsort'] = 'Jobbrendez&eacute;s';
	$lang['strlessthan'] = 'Kisebb mint';
	$lang['strgreaterthan'] = 'Nagyobb mint';
	$lang['stroperatorneedsname'] = 'Meg kell adni az oper&aacute;tornevet.';
	$lang['stroperatorcreated'] = 'Az oper&aacute;tor megteremtve';
	$lang['stroperatorcreatedbad'] = 'Nem siker&uuml;lt megteremteni az oper&aacute;tort.';
	$lang['strconfdropoperator'] = 'Biztosan t&ouml;r&ouml;lni k&iacute;v&aacute;nja &bdquo;%s&rdquo; oper&aacute;tort?';
	$lang['stroperatordropped'] = 'Az oper&aacute;tor t&ouml;r&ouml;lve.';
	$lang['stroperatordroppedbad'] = 'Nem siker&uuml;lt t&ouml;r&ouml;lni az oper&aacute;tort.';

	// Casts
	$lang['strcasts'] = 'Kasztok';
	$lang['strnocasts'] = 'Nincsenek kasztok.';
	$lang['strsourcetype'] = 'Forr&aacute;st&iacute;pus';
	$lang['strtargettype'] = 'C&eacute;lt&iacute;pus';
	$lang['strimplicit'] = 'Implicit';
	$lang['strinassignment'] = '&Eacute;rt&eacute;kad&aacute;sban';
	$lang['strbinarycompat'] = '(Bin&aacute;risan kompatibilis)';
	
	// Conversions
	$lang['strconversions'] = '&Aacute;talak&iacute;t&aacute;sok';
	$lang['strnoconversions'] = 'Nincsenek &aacute;talak&iacute;t&aacute;sok.';
	$lang['strsourceencoding'] = 'Forr&aacute;sk&oacute;dol&aacute;s';
	$lang['strtargetencoding'] = 'C&eacute;lk&oacute;dol&aacute;s';
	
	// Languages
	$lang['strlanguages'] = 'Nyelvek';
	$lang['strnolanguages'] = 'Nincsenek nyelvek.';
	$lang['strtrusted'] = 'Hiteles';
	
	// Info
	$lang['strnoinfo'] = 'Nincs el&eacute;rhet&#337; inform&aacute;ci&oacute;.';
	$lang['strreferringtables'] = 'Kapcsol&oacute;d&oacute; t&aacute;bl&aacute;k';
	$lang['strparenttables'] = 'Sz&uuml;l&#337;t&aacute;bl&aacute;k';
	$lang['strchildtables'] = 'Gyerekt&aacute;bl&aacute;k';

	// Aggregates
	$lang['straggregates'] = 'Aggreg&aacute;ci&oacute;k';
	$lang['strnoaggregates'] = 'Nincsenek aggreg&aacute;tumok.';
	$lang['stralltypes'] = '(Minden t&iacute;pus)';

	// Operator Classes
	$lang['stropclasses'] = 'Oper&aacute;tor-oszt&aacute;lyok';
	$lang['strnoopclasses'] = 'Nincsenek oper&aacute;tor-oszt&aacute;lyok.';
	$lang['straccessmethod'] = 'Hozz&aacute;f&eacute;r&eacute;si elj&aacute;r&aacute;s';

	// Stats and performance
	$lang['strrowperf'] = 'Sorteljes&iacute;tm&eacute;ny';
	$lang['strioperf'] = 'I/O-teljes&iacute;tm&eacute;ny';
	$lang['stridxrowperf'] = 'Indexsor-teljes&iacute;tm&eacute;ny';
	$lang['stridxioperf'] = 'Index-I/O-teljes&iacute;tm&eacute;ny';
	$lang['strpercent'] = '%';
	$lang['strsequential'] = 'Szekvenci&aacute;lis';
	$lang['strscan'] = 'Keres&eacute;s';
	$lang['strread'] = 'Olvas&aacute;s';
	$lang['strfetch'] = 'Leh&iacute;v&aacute;s';
	$lang['strheap'] = 'Kupac';
	$lang['strtoast'] = 'TOAST';
	$lang['strtoastindex'] = 'TOAST Index';
	$lang['strcache'] = 'Gyorst&aacute;r';
	$lang['strdisk'] = 'Lemez';
	$lang['strrows2'] = 'Sorok';

	// Tablespaces
	$lang['strtablespace']  =  'T&aacute;blahely';
	$lang['strtablespaces']  =  'T&aacute;blahelyek';
	$lang['strshowalltablespaces']  =  'Minden t&aacute;blahely megjelen&iacute;t&eacute;se';
	$lang['strnotablespaces']  =  'Nincsenek t&aacute;blahelyek.';
	$lang['strcreatetablespace']  =  'T&aacute;blahely teremt&eacute;se';
	$lang['strlocation']  =  'Hely';
	$lang['strtablespaceneedsname']  =  'Nevet kell adnia a t&aacute;blahelynek.';
	$lang['strtablespaceneedsloc']  =  'Meg kell adnia egy mapp&aacute;t, ahol a t&aacute;blahelyet teremti.';
	$lang['strtablespacecreated']  =  'T&aacute;blahely teremtve.';
	$lang['strtablespacecreatedbad']  =  'T&aacute;blahely teremt&eacute;se sikertelen.';
	$lang['strconfdroptablespace']  =  'Biztosan ki akarja dobni &bdquo;%s&rdquo; t&aacute;blahelyet?';
	$lang['strtablespacedropped']  =  'T&aacute;blahely kidobva.';
	$lang['strtablespacedroppedbad']  =  'T&aacute;blahely kidob&aacute;sa sikertelen.';
	$lang['strtablespacealtered']  =  'T&aacute;blahely megv&aacute;ltoztatva.';
	$lang['strtablespacealteredbad']  =  'T&aacute;blahely megv&aacute;ltoztat&aacute;sa sikertelen.';

	// Miscellaneous
	$lang['strtopbar'] = '%s fut %s:%s c&iacute;men &mdash; &Ouml;n &bdquo;%s&rdquo; n&eacute;ven jelentkezett be. %s';
	$lang['strtimefmt'] = 'Y.m.d. H:i';
	$lang['strhelp'] = 'S&uacute;g&oacute;';
	$lang['strhelpicon']  =  '?';

?>
